Having an thing whose name requires special UTF-8 character to be properly
displayed is a source of portability problem (including xgettext issue
reported by Alwin);

Considering also that this french word is only understood (sparesely) in
Great Britain, but not by international english speaking community;

This patch then replace it by the "Mini-Preview" suggested by Carlos R.
Mafra, which is more likely to be understood.

Signed-off-by: Christophe CURIS <christophe.cu...@free.fr>
---
 WPrefs.app/Icons.c | 10 +++++-----
 src/WindowMaker.h  |  2 +-
 src/actions.c      |  2 +-
 src/balloon.c      |  2 +-
 src/icon.h         |  2 +-
 5 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/src/WindowMaker.h b/src/WindowMaker.h
index e954ee8..ec95075 100644
--- a/src/WindowMaker.h
+++ b/src/WindowMaker.h
@@ -446,7 +446,7 @@ extern struct WPreferences {
        char cycle_ignore_minimized;        /* Ignore minimized windows when 
cycling */
        char strict_windoze_cycle;          /* don't close switch panel when 
shift is released */
        char panel_only_open;               /* Only open the switch panel; 
don't switch */
-       int apercu_size;                    /* Size of apercu preview in pixels 
*/
+       int apercu_size;                    /* Size of Mini-Previews in pixels 
*/
 
        /* All delays here are in ms. 0 means instant auto-action. */
        int clip_auto_raise_delay;          /* Delay after which the clip will 
be raised when entered */
diff --git a/src/actions.c b/src/actions.c
index 03807fc..c465646 100644
--- a/src/actions.c
+++ b/src/actions.c
@@ -1151,7 +1151,7 @@ void wIconifyWindow(WWindow *wwin)
                                        set_icon_apercu(wwin->icon, apercu);
                                        RReleaseImage(apercu);
                                } else {
-                                       wwarning("window apercu creation 
failed");
+                                       wwarning(_("window mini-preview 
creation failed"));
                                }
                        }
                }
diff --git a/src/balloon.c b/src/balloon.c
index 25998e1..8d883d9 100644
--- a/src/balloon.c
+++ b/src/balloon.c
@@ -458,7 +458,7 @@ static void showBalloon(WScreen *scr)
        }
 
        if (wPreferences.miniwin_apercu_balloon && scr->balloon->apercu != None)
-               /* used to display either the apercu alone or the apercu and 
the title */
+               /* used to display either the mini-preview alone or the 
mini-preview with the title */
                showApercu(scr, x, y, scr->balloon->text, scr->balloon->apercu);
        else
                showText(scr, x, y, scr->balloon->h, w, scr->balloon->text);
diff --git a/src/icon.h b/src/icon.h
index 80e9acf..14db37e 100644
--- a/src/icon.h
+++ b/src/icon.h
@@ -29,7 +29,7 @@
 #define TILE_CLIP      1
 #define TILE_DRAWER    2
 
-/* This is the border, in pixel, drawn around an Aperçu */
+/* This is the border, in pixel, drawn around a Mini-Preview */
 #define APERCU_BORDER 1
 
 typedef struct WIcon {
diff --git a/WPrefs.app/Icons.c b/WPrefs.app/Icons.c
index 5c33f5d..76ed866 100644
--- a/WPrefs.app/Icons.c
+++ b/WPrefs.app/Icons.c
@@ -93,7 +93,7 @@ typedef struct _Panel {
 } _Panel;
 
 /*
  * Minimum size for an Apercu:
  * This value is actually twice the size of the minimum icon size choosable.
  * We set the slider min to taht number minus one, because when set to this
  * value WPrefs will consider that the user wants the feature turned off.
@@ -197,7 +197,7 @@ static void showData(_Panel * panel)
                i = 9;
        WMSetPopUpButtonSelectedItem(panel->sizeP, i);
 
-       /* Apercu */
+       /* Mini-Previews for Icons */
        b = GetBoolForKey("MiniwindowApercuBalloons");
        if (b) {
                i = GetIntegerForKey("ApercuSize");
@@ -339,13 +339,13 @@ static void createPanel(Panel * p)
 
        WMMapSubwidgets(panel->sizeF);
 
-       /***************** Apercu ****************/
+       /***************** Mini-Previews ****************/
        panel->apercu.frame = WMCreateFrame(panel->box);
        WMResizeWidget(panel->apercu.frame, 156, 52);
        WMMoveWidget(panel->apercu.frame, 124, 168);
-       WMSetFrameTitle(panel->apercu.frame, _("Miniwindow aperçus"));
+       WMSetFrameTitle(panel->apercu.frame, _("Mini-Previews for Icons"));
 
-       WMSetBalloonTextForView(_("The Aperçu provides a small view of the 
content of the\n"
+       WMSetBalloonTextForView(_("The Mini-Preview provides a small view of 
the content of the\n"
                                  "window when the mouse is placed over the 
@@ -93,7 +93,7 @@ typedef struct _Panel {
 
 /*
- * Minimum size for an Apercu:
+ * Minimum size for a Mini-Preview:
  * This value is actually twice the size of the minimum icon size choosable.
  * We set the slider min to taht number minus one, because when set to this
icon."),
                                WMWidgetView(panel->apercu.frame));
 
-- 
2.1.4


-- 
To unsubscribe, send mail to wmaker-dev-unsubscr...@lists.windowmaker.org.

Reply via email to